"use strict";exports.id=8047,exports.ids=[8047],exports.modules={"./src/commands/disable.ts"(e,s,r){r.r(s),r.d(s,{handleMcpDisable:()=>n});var o=r("../../../../var/folders/gy/wcfhjzc55d96bnvx1zv223lc0000gn/T/agent-cli-mac-macos-x64-019f6d3d-8812-4a7d-ad69-e1d1701ab9a2.1ELq4Ger/pnpm-virtual-store/chalk@5.6.2/node_modules/chalk/source/index.js"),a=r("./src/console-io.ts"),d=r("./src/mcp/disabled-store.ts"),t=r("./src/mcp/project-paths.ts");function n(e,s){return r=this,n=void 0,i=function*(){var e;try{const e=process.cwd(),{disabledPath:r}=(0,t.C)(e),n=new d.P(r),c=yield n.isServerDisabled(s);c||(yield n.addDisabledServer(s)),c?(0,a.OT)(o.Ay.yellow(`MCP server '${s}' was already disabled`)):(0,a.OT)(o.Ay.green(`✓ Disabled MCP server: ${s}`)+"\n"+o.Ay.dim("The server will no longer be loaded or prompted for approval.")),process.exit(0)}catch(s){const r=null!==(e=null==s?void 0:s.message)&&void 0!==e?e:String(s);(0,a.p2)(o.Ay.red(`Failed to disable MCP server: ${r}`)),process.exit(1)}},new((c=void 0)||(c=Promise))((function(e,s){function o(e){try{d(i.next(e))}catch(e){s(e)}}function a(e){try{d(i.throw(e))}catch(e){s(e)}}function d(s){var r;s.done?e(s.value):(r=s.value,r instanceof c?r:new c((function(e){e(r)}))).then(o,a)}d((i=i.apply(r,n||[])).next())}));var r,n,c,i}}};