"use strict";exports.id=8860,exports.ids=[8860],exports.modules={"./src/utils/labels-file-parser.ts"(e,r,s){s.r(r),s.d(r,{parseJsonLabelsFile:()=>o,parseTomlLabelsFile:()=>n});var t=s("../../../../var/folders/gy/wcfhjzc55d96bnvx1zv223lc0000gn/T/agent-cli-mac-macos-x64-019f6d3d-8812-4a7d-ad69-e1d1701ab9a2.1ELq4Ger/pnpm-virtual-store/smol-toml@1.6.1/node_modules/smol-toml/dist/index.js");function o(e,r){const s=JSON.parse(e);if(Array.isArray(s)){const e=[];for(const t of s){if("object"!=typeof t||null===t||!("key"in t)||!("value"in t)||"string"!=typeof t.key||"string"!=typeof t.value)throw new Error(`Invalid label entry in ${r}: expected {key: string, value: string}`);e.push({key:t.key,value:t.value})}return e}if("object"==typeof s&&null!==s){const e=[];for(const[t,o]of Object.entries(s))if("string"==typeof o)e.push({key:t,value:o});else{if(!Array.isArray(o))throw new Error(`Invalid label value for key "${t}" in ${r}: expected string or array of strings`);for(const s of o){if("string"!=typeof s)throw new Error(`Invalid label value for key "${t}" in ${r}: array values must be strings`);e.push({key:t,value:s})}}return e}throw new Error(`Invalid labels file format in ${r}: expected array or object`)}function n(e,r){const s=(0,t.qg)(e),o=[];for(const[e,t]of Object.entries(s))if("string"==typeof t)o.push({key:e,value:t});else{if(!Array.isArray(t))throw new Error(`Invalid label value for key "${e}" in ${r}: expected string or array of strings`);for(const s of t){if("string"!=typeof s)throw new Error(`Invalid label value for key "${e}" in ${r}: array values must be strings`);o.push({key:e,value:s})}}return o}}};